##  Overview
Calculate the business value of your AI agents, such as the total expected cost savings, risk reduction, and revenue increase. With calculations, the target fact sheet fields populate automatically based on the values from other fields. This eliminates the need for manual updates.
![Summary showing cost savings, revenue increase, and risk reduction for an AI agent.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio105fa840126347c384e2a74bf73736fb_LowRes.png)
Calculated Fields on an AI Agent Fact Sheet with Example Values
